# disposable-email-validator

### installation

```
pip install disposable-email-validator
```


### usage

```python
from disposable_email_validator import is_disposable_email

is_disposable_email("some_email@inpwa.com") # True
is_disposable_email("some_email@gmail.com") # False
```